//The following code is a modified version of split global
//that generates two scripts, one a shell script, and the other a rasmol script
//the shell script is used to add bonds to the rasmol image, the rasmol script
//is run to draw those bonds correctly.
//If you want to change aesthetics, work within the draw function starting at line 285
//
//Greg Grothaus 6/30/04

#include<iostream>
#include<map>
#include<queue>
#include<vector>
#include<fstream>
#include<string>
#include<algorithm>
#include<sstream>
#include<cstdlib>

using namespace std;

#define svector std::vector
#define sstring std::string
#define lstring leda::string
#define smap std::map


svector<svector<int> > connected_components(svector<svector<double> > in);
void draw(svector<svector<double> > matrix,double);


//converts an integer to a string
template <class T> sstring toa(T in)
{
	stringstream ss;
	ss<<in;
	sstring out;
	ss>>out;
	return out;
}
template <class T> T ato(sstring in)
{
	stringstream ss;
	ss<<in;
	T out;
	ss>>out;
	return out;
}

svector<sstring> residues;
svector<sstring> residuesNoSpace;
int main(int argc,  char** argv) 
{
	sstring usage="Usage: split <gfile> <size>\n";
	if(argc<3)
	{
		cout<<argc;
		cout<<usage;
		exit(1);
	}

	//open .g file
	ifstream in_g(argv[1]);
	if(!in_g.is_open())
	{
		cout<<"FAILED\nCould not open "<<argv[1]<<"\n"<<usage;
		exit(1);
	}

	double sites=ato<double>(argv[2])/331.842;
	
	//read in pkint file
	svector<sstring> pkint;
	
	while(!cin.eof())
	{
		sstring temp;
		getline(cin,temp,'\n');
		if(temp.length()>1)
		{
			pkint.push_back(temp);
			stringstream ss;
			ss<<temp;
			sstring data,num;
			ss>>data>>data>>data>>num;
			residues.push_back(data+" "+num);
			residuesNoSpace.push_back(data+num);
		}
			
	}
		
	//read in .g file
	svector<svector<double> > matrix;
	double minw=9999, maxw=-9999;
	for(int i=0;i<pkint.size();i++)
	{
		svector<double> row;
		for(int j=0;j<pkint.size();j++)
		{
			int trash;
			in_g>>trash>>trash;	//assuming numbers are in order
			double d;
			in_g>>d;
			row.push_back(d);
			if(d<minw) minw=d;
			if(d>maxw) maxw=d;
		}
		matrix.push_back(row);
	}

	draw(matrix,sites);
}

void draw(svector<svector<double> > matrix,double min)
{
	double d=0;
	
	double maxw=-1,minw=50;
	for(int i=0;i<matrix.size();i++)
	{
		for(int j=0;j<i;j++)
		{
			if(matrix[i][j]<min)
				matrix[i][j]=0;
			else if(matrix[i][j]>maxw)
				maxw=matrix[i][j];
			if(matrix[i][j]<minw && matrix[i][j]!=0)
				minw=matrix[i][j];
		}
	}

	maxw-=minw; //we will subtract minw from all the bond weights, then ask size as percentage of maxw
	
	for(int i=0;i<matrix.size();i++)
	{
		for(int j=0;j<i;j++)
		{
			if(matrix[i][j]!=0)
			{
				int bondwidth=int(100*(matrix[i][j]-minw)/maxw);
				int redness=int(63*((matrix[i][j]-minw)/maxw))*4;

				cout<<residues[i]<<"\t"<<residues[j]<<"\t"<<residuesNoSpace[i]<<"\t"<<residuesNoSpace[j]<<"\t"<<bondwidth<<"\t"<<redness<<endl;
			}
		}
	}
}
